% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{f_dose_new_cpp}
\alias{f_dose_new_cpp}
\title{Dosing Date Imputation for New Patients}
\usage{
f_dose_new_cpp(
  usubjid,
  V,
  C,
  D,
  model_k0,
  theta_k0,
  model_t0,
  theta_t0,
  model_t1,
  theta_t1,
  model_ki,
  theta_ki,
  model_ti,
  theta_ti
)
}
\arguments{
\item{usubjid}{The unique subject ID.}

\item{V}{Initialized to 0 and corresponds to the randomization visit.}

\item{C}{The cutoff date relative to randomization.}

\item{D}{The discontinuation date relative to randomization.}

\item{model_k0}{The model for the number of skipped
visits between randomization and the first drug dispensing visit.
Options include "constant", "poisson", "zero-inflated poisson",
and "negative binomial".}

\item{theta_k0}{The model parameters for the number of skipped
visits between randomization and the first drug dispensing visit.}

\item{model_t0}{The model for the gap time between randomization
and the first drug dispensing visit when there is no visit skipping.
Options include "constant", "exponential", "weibull",
"log-logistic", and "log-normal".}

\item{theta_t0}{The model parameters for the gap time between
randomization and the first drug dispensing visit when there is
no visit skipping.}

\item{model_t1}{The model for the gap time between randomization
and the first drug dispensing visit when there is visit skipping.
Options include "least squares", and "least absolute deviations".}

\item{theta_t1}{The model parameters for the gap time between
randomization and the first drug dispensing visit when there is
visit skipping.}

\item{model_ki}{The model for the number of skipped
visits between two consecutive drug dispensing visits.
Options include "constant", "poisson", "zero-inflated poisson",
and "negative binomial".}

\item{theta_ki}{The model parameters for the number of skipped
visits between two consecutive drug dispensing visits.}

\item{model_ti}{The model for the gap time between two consecutive
drug dispensing visits. Options include "least squares"
and "least absolute deviations".}

\item{theta_ti}{The model parameters for the gap time between
two consecutive drug dispensing visits.}
}
\value{
A data frame with two variables:
\itemize{
\item \code{usubjid}: The unique subject ID.
\item \code{day}: The dosing visit date relative to randomization.
}
}
\description{
Imputes the dosing dates for new patients and ongoing
patients with no dosing records.
}
\examples{
set.seed(529)

f_dose_new_cpp(
  usubjid = "Z001", V = 0, C = 87, D = 985,
  model_k0 = "zero-inflated poisson", theta_k0 = c(0.6, 1.1),
  model_t0 = "log-logistic", theta_t0 = c(-1.0, 0.7),
  model_t1 = "least squares", theta_t1 = c(21.5, 1.9),
  model_ki = "zero-inflated poisson", theta_ki = c(0.1, 0.4),
  model_ti = "least squares", theta_ti = c(21, 2.3))

}
\author{
Kaifeng Lu, \email{kaifenglu@gmail.com}
}
